@@ -5,6 +5,19 @@ from radar.models.place import Place
 
 
 class RadarContext(Model):
+    """Location context
+    
+    Parameters:
+        live (bool)
+        geofences (`list` of :class:`~radar.models.geofence.Geofence`)
+        place (`list` of :class:`~radar.models.place.Place`, optional)
+        country (:class:`~radar.models.region.Region`, optional)
+        state (:class:`~radar.models.region.Region`, optional)
+        dma (:class:`~radar.models.region.Region`, optional)
+        postalCode (:class:`~radar.models.region.Region`, optional)
+        fraud (FraudObject, optional)
+    """
+
     OBJECT_NAME = "Context"
     _DISPLAY_ATTRIBUTES = (
         "live",
@@ -20,7 +33,7 @@ class RadarContext(Model):
         """Initialize a Radar Model instance
 
         Args:
-            radar (RadarClient): RadarClient for instance CRUD actions
+            radar (:class:`~radar.RadarClient`): RadarClient for instance CRUD actions
             raw_json (dict): raw data to initialize the model with
         """
         self._radar = radar
